<?php
/**
 * Class: WTH_Model_Helpful
 * @author Flipper Code <hello@flippercode.com>
 * @package Maps
 * @version 3.0.0
 */

if ( ! class_exists( 'WTH_Model_Helpful' ) ) {

	/**
	 * Layout model for CRUD operation.
	 * @package Maps
	 * @author Flipper Code <hello@flippercode.com>
	 */
	class WTH_Model_Helpful extends FlipperCode_Model_Base
	{
		/**
		 * Validations on location properies.
		 * @var array
		 */
		public $validations = array();
		/**
		 * Intialize rule object.
		 */
		public function __construct() {
			$this->table = WTH_TBL_HELPFUL;
			$this->unique = 'log_id';
		}
		/**
		 * Admin menu for CRUD Operation
		 * @return array Admin meny navigation(s).
		 */
		public function navigation() {

			return array(
			'wth_form_helpful' => __( 'Plugin Settings', WTH_TEXT_DOMAIN ),
			);
		}
		/**
		 * Install table associated with Rule entity.
		 * @return string SQL query to install post_widget_rules table.
		 */
		public function install() {

			global $wpdb;

			$sql = 'CREATE TABLE IF NOT EXISTS '.$wpdb->prefix.'wthp_helpful_log (
			log_id int unsigned auto_increment unique,
			post_id int(11) NOT NULL,
			title varchar(500) DEFAULT NULL,
			blog_id int(11) DEFAULT NULL,
			helpful char(3) DEFAULT NULL,
			message varchar(1000)  CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
			ip_address varchar(25) DEFAULT NULL,
			user_id int(11) NOT NULL default "0",
			created date NOT NULL,
			primary key(log_id)
			) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci AUTO_INCREMENT=1';

			return $sql;
		}
		/**
		 * Get Rule(s)
		 * @param  array $where  Conditional statement.
		 * @return array         Array of Rule object(s).
		 */
		public function fetch($where = array()) {

			$objects = $this->get( $this->table, $where );

			if ( isset( $objects ) ) {
				foreach ( $objects  as $object ) {
					$object->layout_log_id = unserialize( $object->layout_log_id );
					$object->layout_post_setting = unserialize( $object->layout_post_setting );
				}
				return $objects;
			}
		}

		/**
		 * Save Settings
		*/
		public function save() {
			
			$data = array();
			
			//Nonce Security Verification
			if ( isset( $_REQUEST['_wpnonce'] ) ) {	$nonce = sanitize_text_field( wp_unslash( $_REQUEST['_wpnonce'] ) ); }
			if ( isset( $nonce ) and ! wp_verify_nonce( $nonce, 'wpgmp-nonce' ) ) {	die( 'Cheating...' ); }
			
			//Error Handling
			$this->verify( $_POST );
			if ( is_array( $this->errors ) and ! empty( $this->errors ) )
			$this->throw_errors();
			
			// Reset Reviews
			if( isset($_POST['reset_reviews']) && $_POST['reset_reviews'] == 'true' ) {
				global $wpdb;
				$wpdb->query('DELETE FROM '.$this->table);
				$wpdb->query('DELETE FROM '.$wpdb->prefix.'postmeta where meta_key="_wthp_helpfull_post_yes"');
				$wpdb->query('DELETE FROM '.$wpdb->prefix.'postmeta where meta_key="_wthp_helpfull_post_no"');
			}

			$postedData = $_POST;
			unset($postedData['_wpnonce']);
			unset($postedData['_wp_http_referer']);
			
			//Save Sanitized Form Data
			foreach($postedData['wthp_option_settings'] as $key => $setting) {
				
				if($key == 'post_type_enable')
				continue;
				
				$postedData['wthp_option_settings'][$key] = sanitize_text_field($setting);
			}
			
			update_option( 'wthp_option_settings', $postedData );
			$response['success'] = __( 'Was This Helpful Setting(s) Saved Successfully.',WPGMP_TEXT_DOMAIN );
			return $response;
		}

		/**
		 * Delete rule object by id.
		 */
		public function delete() {
			if ( isset( $_GET['log_id'] ) ) {
				$id = intval( wp_unslash( $_GET['log_id'] ) );
				$connection = FlipperCode_Database::connect();
				$this->query = $connection->prepare( "DELETE FROM $this->table WHERE $this->unique='%d'", $id );
				return FlipperCode_Database::non_query( $this->query, $connection );
			}
		}
	}
}
