<?php
/**
 * Was This Helpful class file.
 * @package Posts
 * @author Flipper Code <hello@flippercode.com>
 * @version 1.0.4
 */

/*
Plugin Name: Was This Helpful
Plugin URI: http://www.flippercode.com/
Description: Get reviews about posts/pages from visitors to make your blog more valuable for readers.
Author: flippercode
Author URI: http://www.flippercode.com/
Version: 1.0.4
Text Domain: was_this_helpful
Domain Path: /lang/
*/

if ( ! defined( 'ABSPATH' ) ) {
	die( 'You are not allowed to call this page directly.' );
}
if( !class_exists( 'FC_Plugin_Base_Lite' ) ) {
   $pluginClass =  plugin_dir_path( __FILE__ ). '/core/class.plugin-lite.php';
   if( file_exists( $pluginClass ) )
   include( $pluginClass );
}

if ( ! class_exists( 'Was_This_Helpful' ) and class_exists( 'FC_Plugin_Base_Lite' ) ) {
	/**
	 * Main plugin class
	 * @author Flipper Code <hello@flippercode.com>
	 * @package Was_This_Helpful
	 */
	class Was_This_Helpful extends FC_Plugin_Base_Lite
	{
		/**
		 * List of Modules.
		 * @var array
		 */
		private $modules = array();
		protected $dboptions;

		/**
		 * Intialize variables, files and call actions.
		 * @var array
		 */
		public function __construct() {

			error_reporting( E_ERROR | E_PARSE );
			parent::__construct( $this->_plugin_definition() );
			$this->register_hooks();
		}

		function _plugin_definition() {

			$this->pluginPrefix = 'wth';
			$pluginClasses = array('wth-form.php','wth-controller.php','wth-model.php','class.public.php' );
			$pluginModules = array( 'overview','helpful','shortcode');
			$pluginCssFilesFrontEnd = array( 'wth-frontend.css' );
			$pluginCssFilesBackendEnd = array('select2.css','wth-backend.css');
			$pluginJsFilesFrontEnd = array('wth-frontend.js');
			$pluginJsFilesBackEnd = array('wth-backend.js','select2.js');
			$pluginData = array('childFileRefrence' => __FILE__,
								'childClassRefrence' => __CLASS__,
								'pluginPrefix' => $this->pluginPrefix,
								'pluginDirectory' => plugin_dir_path( __FILE__ ),
								'pluginTextDomain' => 'was_this_helpful',
								'pluginURL' =>  plugin_dir_url( __FILE__ ),
								'dboptions' => 'wthp_option_settings',
								'controller' => 'WTH_Controller',
								'model' => 'WTH_Model',
								'pluginLabel' => 'Was This Helpful',
								'pluginClasses' =>  $pluginClasses,
								'pluginmodules' => $pluginModules,
								'pluginmodulesprefix' => 'WTH_Model_',
								'pluginCssFilesFrontEnd' => $pluginCssFilesFrontEnd,
								'pluginCssFilesBackEnd' => $pluginCssFilesBackendEnd,
								'pluginJsFilesFrontEnd' => $pluginJsFilesFrontEnd,
								'pluginJsFilesBackEnd' => $pluginJsFilesBackEnd,
								'loadCustomizer' => false);

							return $pluginData;
		}


		function register_hooks(){

			add_action( 'admin_init', array( $this, 'wthp_export_data' ) );
			add_action( 'init', array( $this, '_init' ) );
			add_action( 'wp_ajax_wth_ajax_call',array( $this, 'wth_ajax_call' ) );
			add_action( 'wp_ajax_nopriv_wth_ajax_call', array( $this, 'wth_ajax_call' ) );
			add_shortcode( 'was-this-helpful', array( $this, 'wth_display_shortcode' ) );
			
		}
		
		/**
		 * Export CSV Data.
		 */
		function wthp_export_data() {
			
			if ( isset($_POST['operation']) and 'export' == sanitize_text_field( wp_unslash( $_POST['operation'] ) ) ) {
				$modelFactory = new WTH_Model();
				$helpful_obj = $modelFactory->create_object( 'helpful' );
				$helpful_obj->export();
				exit;
			}
		}
		
		/**
		 * Display posts on the frontend using wth_display_shortcode shortcode.
		 * @param  array  $atts   Template Options.
		 * @param  string $content Content.
		 */
		function wth_display_shortcode($atts, $content = null) {

			try {
				$factoryObject = new WTH_Controller();
				$viewObject = $factoryObject->create_object( 'shortcode' );
				$output = $viewObject->display( 'was-this-helpful',$atts );
				return $output;

			} catch (Exception $e) {
				echo FlipperCode_HTML_Markup::show_message( array( 'error' => $e->getMessage() ) );
			}
		}
		/**
		 * Ajax Call
		 */
		function wth_ajax_call() {

			check_ajax_referer( 'wth-call-nonce', 'nonce' );
			$operation = sanitize_text_field( wp_unslash( $_POST['operation'] ) );
			$value = wp_unslash( $_POST );
			if ( isset( $operation ) ) {
				$this->$operation($value);
			}
			exit;
		}

		function wthp_add_post_log( $post_id, $status, $message = '' ) {

			global $wpdb, $blog_id;

			$log_data = array(

			'post_id' => $post_id,

			'title' => get_the_title( $post_id ),

			'blog_id' => $blog_id,

			'helpful' => $status,

			'message' => $message,

			'ip_address' => get_client_ip(),

			'user_id' => get_current_user_id(),

			'created' => date( 'Y-m-d' ),

			);

			$ret = $wpdb->insert( $wpdb->base_prefix.'wthp_helpful_log', $log_data );

			return $wpdb->insert_id;

		}

		function wthp_filter_helpful_content( $content ) {

			global $post, $wp_query;
			$shortcode = '[was-this-helpful';
			$check = strpos( $content,$shortcode );
			if ( $check !== false ) { 
				return $content;
			}
			
			$content .= do_shortcode( '[was-this-helpful id='.$post->ID.']' );
			return $content;

		}
		
		function wthp_log_feedback($value) {

			$wthp_option = $this->dboptions;
			$login_required = false;
			
			if(array_key_exists('wthp_option_settings',$wthp_option)) 
			$login_required = $wthp_option['wthp_option_settings']['login_required'];
			else
			$login_required = $wthp_option['login_required'];
			if($login_required == 'true')
			$login_required = true;
			
			if ( !is_user_logged_in() and $login_required  ) {

				$resp['error'] = true;
				$resp['message'] = $wthp_option['wthp_option_settings']['login_message'];
				echo json_encode( $resp );
				exit;
			}
			$post_id = (int) $value['post_id'];

			$status = ($value['response'] == 1) ? 'yes' : 'no';

			$nonce = $value['_wpnonce'];

			$thank = $wthp_option['hlp_text_thank'] ?  $wthp_option['hlp_text_thank'] : __( 'Thank You for your feedback.', 'wthp' );

			 $message = isset( $value['message'] ) ? strip_tags( esc_textarea( wp_unslash( $value['message'] ) ) ) : '';

			if ( wthp_already_voted( $post_id ) ) {

				$resp['error'] = true;

				$resp['message'] = __( 'You have already vote this post.' ,'wthp' );

				set_transient( wthp_get_transient_key( $post_id ), true, 60 * 60 * 24 );

			} else {

				$id = $this->wthp_add_post_log( $post_id, $status, $message );

				$resp['success'] = true;

				$resp['message'] = $thank;

				if ( $status == 'yes' ) {

					$y = get_post_meta( $post_id, '_wthp_helpfull_post_yes', true );

					if ( $y == '' ) {

						$y = 0; }

					$y++;

					update_post_meta( $post_id, '_wthp_helpfull_post_yes', $y );

				} else {

					$n = get_post_meta( $post_id, '_wthp_helpfull_post_no', true );

					if ( $n == '' ) {

						$n = 0; }

					$n++;

					update_post_meta( $post_id, '_wthp_helpfull_post_no', $n );

					$resp['message'] = $thank;

				}
			}

			echo json_encode( $resp );

			exit;
		}

		/**
		 * Call WordPress hooks.
		 */
		function _init() {
			
			$this->dboptions = maybe_unserialize(get_option( 'wthp_option_settings' ));
			global $wpdb;
			add_filter( 'the_content', array( $this, 'wthp_filter_helpful_content' ) );
			if(array_key_exists('wthp_option_settings',$this->dboptions)) 
			$post_types = $this->dboptions['wthp_option_settings']['post_type_enable'];
			else
			$post_types = $this->dboptions['post_type_enable'];
			
			if ( !empty($post_types) ) {

				foreach ( $post_types as $type ) {
					add_filter( 'manage_edit-'.$type.'_columns', array($this,'wthp_columns_head') );
					add_action( 'manage_'.$type.'_posts_custom_column' , array($this,'wthp_columns_content'), 10, 2 );
					add_filter( 'manage_edit-post_sortable_columns', array($this,'wthp_columns_sortable') );
				}
			}
			add_filter( 'plugin_action_links_'.plugin_basename(__FILE__), array($this,'plugin_action_links') );
			add_filter( 'plugin_row_meta', array($this,'plugin_row_meta'), 10,2 );

		}
		/**
		 * Settings link.
		 * @param  array $links Array of Links.
		 * @return array        Array of Links.
		 */
		function plugin_row_meta( $links, $file ) {

			if( basename(dirname($file)) == 'was-this-helpful' ) {
				$links[] = '<a href="http://www.flippercode.com/product/was-this-helpful/" target="_blank">Upgrade to Pro</a>';
		   		$links[] = '<a href="http://www.flippercode.com/forums" target="_blank">Support Forums</a>';
			}

		   return $links;
		}
		/**
		 * Settings link.
		 * @param  array $links Array of Links.
		 * @return array        Array of Links.
		 */
		function plugin_action_links( $links ) {
		   $links[] = '<a href="'. esc_url( get_admin_url(null, 'admin.php?page=wth_form_helpful') ) .'">Settings</a>';
		   return $links;
		}

		/**
		 * Create backend navigation.
		 */
		function define_admin_menu() {

			$pagehook1 = add_menu_page(
				__( 'Was This Helpful', WTH_TEXT_DOMAIN ),
				__( 'Was This Helpful', WTH_TEXT_DOMAIN ),
				'wth_admin_overview',
				WTH_SLUG,
				array( $this,'processor' ),
				esc_url(WTH_IMAGES.'fc-small-logo.png')
			);
			return $pagehook1;
		}


		/**
		 * Eneque scripts in the backend.
		 */
		function backend_script_localisation() {

			$wth_js_lang = array();
			$wth_js_lang['ajax_url'] = admin_url( 'admin-ajax.php' );
			$wth_js_lang['nonce'] = wp_create_nonce( 'wth-call-nonce' );
			$wth_js_lang['confirm'] = __( 'Are you sure to delete item?',WTH_TEXT_DOMAIN );
			wp_localize_script( 'wth-backend', 'wth_js_lang', $wth_js_lang );
		}

		function wthp_columns_head( $defaults ) {

			$defaults['helpfull_yes'] = __( 'Helpful Yes?', WTH_TEXT_DOMAIN );
			$defaults['helpfull_no'] = __( 'Helpful No?', WTH_TEXT_DOMAIN );
			return $defaults;

		}

		function wthp_columns_content( $column, $post_id ) {

			global $wpdb, $blog_id;

			$message = '';

			$table = WTH_TBL_HELPFUL;

			if ( $column == 'helpfull_yes' ) {
				$yes_res = $wpdb->get_results( 'select log_id from '.$table.' where post_id = '.$post_id.' AND blog_id='.$blog_id." AND helpful='yes'" );

				if ( count( $yes_res ) > 0 ) {

					$hlp_yes = count( $yes_res );

				} else {
					$hlp_yes = 0;
				}
				echo "<a class='button-primary' href='javascript:;' >".__( 'Yes', 'wthp' )." ( $hlp_yes )</a>";

			} elseif ( $column == 'helpfull_no' ) {
				$no_res = $wpdb->get_results( 'select log_id from '.$table.' where post_id = '.$post_id.' AND blog_id='.$blog_id." AND helpful='no'" );
				if ( count( $no_res ) > 0 ) {
					$hlp_no = count( $no_res );
				} else {
					$hlp_no = 0;
				}
				echo "<a class='button-secondary' href='javascript:;' >".__( 'No', 'wthp' )." ( $hlp_no )</a>";
			}
		}

		function wthp_columns_sortable( $columns ) {
			$columns['helpfull_yes'] = 'helpfull_yes';
			$columns['helpfull_no'] = 'helpfull_no';
			return $columns;
		}

		/**
		 * Define all constants.
		 */
		 function _define_constants() {

			global $wpdb;

			if ( ! defined( 'WTH_SLUG' ) ) {
				define( 'WTH_SLUG', 'wth_view_overview' );
			}

			if ( ! defined( 'WTH_VERSION' ) ) {
				define( 'WTH_VERSION', '1.0.4' );
			}

			if ( ! defined( 'WTH_TEXT_DOMAIN' ) ) {
				define( 'WTH_TEXT_DOMAIN', 'was_this_helpful' );
			}

			if ( ! defined( 'WTH_FOLDER' ) ) {
				define( 'WTH_FOLDER', basename( dirname( __FILE__ ) ) );
			}

			if ( ! defined( 'WTH_DIR' ) ) {
				define( 'WTH_DIR', plugin_dir_path( __FILE__ ) );
			}

			if ( ! defined( 'WTH_CORE_CLASSES' ) ) {
				define( 'WTH_CORE_CLASSES', WTH_DIR.'core/' );
			}

			if ( ! defined( 'WTH_PLUGIN_CLASSES' ) ) {
				define( 'WTH_PLUGIN_CLASSES', WTH_DIR.'classes/' );
			}

			if ( ! defined( 'WTH_CONTROLLER' ) ) {
				define( 'WTH_CONTROLLER', WTH_CORE_CLASSES );
			}

			if ( ! defined( 'WTH_CORE_CONTROLLER_CLASS' ) ) {
				define( 'WTH_CORE_CONTROLLER_CLASS', WTH_CORE_CLASSES.'class.controller.php' );
			}

			if ( ! defined( 'WTH_Model' ) ) {
				define( 'WTH_Model', WTH_DIR.'modules/' );
			}

			if ( ! defined( 'WTH_URL' ) ) {
				define( 'WTH_URL', plugin_dir_url( WTH_FOLDER ).WTH_FOLDER.'/' );
			}

			if ( ! defined( 'FC_CORE_URL' ) ) {
				define( 'FC_CORE_URL', plugin_dir_url( WTH_FOLDER ).WTH_FOLDER.'/core/' );
			}

			if ( ! defined( 'WTH_INC_URL' ) ) {
				define( 'WTH_INC_URL', WTH_URL.'includes/' );
			}

			if ( ! defined( 'WTH_VIEWS_PATH' ) ) {
				define( 'WTH_VIEWS_PATH', wth_CLASSES.'view' );
			}

			if ( ! defined( 'WTH_CSS' ) ) {
				define( 'WTH_CSS', WTH_URL.'/assets/css/' );
			}

			if ( ! defined( 'WTH_JS' ) ) {
				define( 'WTH_JS', WTH_URL.'/assets/js/' );
			}

			if ( ! defined( 'WTH_IMAGES' ) ) {
				define( 'WTH_IMAGES', WTH_URL.'/assets/images/' );
			}

			if ( ! defined( 'WTH_FONTS' ) ) {
				define( 'WTH_FONTS', WTH_URL.'fonts/' );
			}

			if ( ! defined( 'WTH_TBL_HELPFUL' ) ) {
				define( 'WTH_TBL_HELPFUL', $wpdb->prefix.'wthp_helpful_log' );
			}

		}

	}

  new Was_This_Helpful();
  
}


